#include "stdinc.h"
#include "client.h"
#include "irc_string.h"
#include "send.h"
#include "numeric.h"
#include "ircd.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"
#include "s_serv.h"
#include "hash.h"
#include "s_conf.h"
#include "hook.h"

static struct Client *toy_p = NULL;
static struct Client *jupe_p = NULL;

static int s_toy_message(struct h_fake_message_data *);
static int s_toy_kill(struct Client *);
static int s_toy_skill(struct Client *);
static int s_toy_squit(struct Client *);
static int s_toy_collision(struct Client *);

void
_modinit(void)
{
	hook_add_hook("fake_message", (hookfn) s_toy_message);
	hook_add_hook("fake_kill", (hookfn) s_toy_kill);
	hook_add_hook("fake_skill", (hookfn) s_toy_skill);
	hook_add_hook("fake_squit", (hookfn) s_toy_squit);
	hook_add_hook("fake_collision", (hookfn) s_toy_collision);

	toy_p = create_fake_client("toy", "toy", "toy.lan", "fls service toy", 1);
	jupe_p = create_fake_server("toy.jupe", "fls toy jupe", 1);
}

void
_moddeinit(void)
{
	hook_del_hook("fake_message", (hookfn) s_toy_message);
	hook_del_hook("fake_kill", (hookfn) s_toy_kill);
	hook_del_hook("fake_skill", (hookfn) s_toy_skill);
	hook_del_hook("fake_squit", (hookfn) s_toy_squit);
	hook_del_hook("fake_collision", (hookfn) s_toy_collision);

	destroy_fake_client(toy_p);
	destroy_fake_server(jupe_p, 1);
}

const char *_version = "$Revision$";

static int
s_toy_message(struct h_fake_message_data *hd)
{
	if(hd->target_p != toy_p)
		return 0;

	sendto_realops_flags(UMODE_ALL, L_ALL,
			"Received: %s // From: %s // Direct: %s // Message: %s",
			hd->notice ? "NOTICE" :	"PRIVMSG",
			hd->source_p->name,
			hd->direct ? "YES" : "NO", hd->message);
	return 0;
}

static int
s_toy_kill(struct Client *target_p)
{
	if(target_p != toy_p)
		return 0;

	sendto_realops_flags(UMODE_ALL, L_ALL, "Toy was killed (oper).");
	return 0;
}

static int
s_toy_skill(struct Client *target_p)
{
	if(target_p != toy_p)
		return 0;

	sendto_realops_flags(UMODE_ALL, L_ALL, "Toy was killed (server).");
	return 0;
}

static int
s_toy_squit(struct Client *target_p)
{
	if(target_p != jupe_p)
		return 0;

	sendto_realops_flags(UMODE_ALL, L_ALL, "Toy was squit.");
	return 0;
}

static int
s_toy_collision(struct Client *target_p)
{
	if(target_p != toy_p)
		return 0;

	sendto_realops_flags(UMODE_ALL, L_ALL, "Toy was collided.");
	return 0;
}

